![PyPI - Python Version](https://img.shields.io/pypi/pyversions/tidal-stability) ![PyPI - License](https://img.shields.io/pypi/l/tidal-stability) [![codecov](https://codecov.io/gh/YourLocalBlake/TidalStability/branch/master/graph/badge.svg?token=89VFTvptUh)](https://codecov.io/gh/YourLocalBlake/TidalStability)

## Tidal Stability
---

This is the repo for my code related to my masters of research where I am modelling gas clouds in close proximity to 
black holes.
